@@ -3,7 +3,7 @@
 int max_nchar(SEXP x) {
   errIfNotStr(x, "x");
   R_xlen_t N = xlength(x);
-  const SEXP * xp = STRING_PTR(x);
+  const SEXP * xp = STRING_PTR_RO(x);
   int m = length(xp[0]);
   for (R_xlen_t i = 1; i < N; ++i) {
     if (length(xp[i]) <= m) {
@@ -17,7 +17,7 @@ int max_nchar(SEXP x) {
 void err_if_nchar_geq(SEXP x, int max_nchar, const char * vx) {
   errIfNotStr(x, "x");
   R_xlen_t N = xlength(x);
-  const SEXP * xp = STRING_PTR(x);
+  const SEXP * xp = STRING_PTR_RO(x);
   for (R_xlen_t i = 0; i < N; ++i) {
     if (length(xp[i]) >= max_nchar) {
       const char * xi = CHAR(xp[i]);
